% Parameter
tspan = [0 3000];
y0 = [2 0];
mu = 1000.;

% rechte Seite der Van der Pol DGL
f = @(t,y) [y(2); mu*(1. - y(1)^2)*y(2) - y(1)];

% expliziter Loeser (ode45)
disp('Loeser: ode45');
tic;
[t45 ,y45 ] = ode45 (f,tspan,y0);
toc

% impliziter Loeser (ode23s)
disp('Loser: ode23s');
tic;
[t23s,y23s] = ode23s(f,tspan,y0);
toc

% plotte Loesung
figure(1);
clf;
plot(t45 ,y45 (:,1),'r--x')
hold on;
plot(t23s,y23s(:,1),'b-o')
title('Van der Pol DGL (Loesung)')
xlabel('t');
ylabel('y')
legend('ode45 (explizit)','ode23s (implizit)');
% print('vanDerPol_y.eps','-depsc')

% plotte Schrittweite
figure(2);
clf;
semilogy(t45 (2:end),diff(t45 ),'b-x');
hold on;
semilogy(t23s(2:end),diff(t23s),'r-o');
title('Van der Pol DGL (Schrittweite)')
xlabel('t');
ylabel('h')
legend('ode45 (explizit)','ode23s (implizit)');
% print('vanDerPol_h.eps','-depsc')

% plotte Steifigkeitsparameter entlang Loesungskurve
% Berechnen sie den Steifigkeitsparameter entlang Loesungskurve
t23s = 0.;
S23s = 0.;
figure(3)
clf;
semilogy(t23s,S23s,'b-o')
title('Van der Pol DGL (Steifigkeitsparameter)')
xlabel('t');
ylabel('S')
% print('vanDerPol_S.eps','-depsc')
