% definiere AWP
alpha = 1;
A = [0, +alpha; -alpha, 0;];
f = @(t, y) y*A;
tspan = [0., 100.];
y0 = [1.; 0.];

% integriere AWP (es sind auch andere Verfahren implementiert...  ungeniert
% experimentieren :-)
Nsteps = 300;
[t1, y1] = ode_integrate(f, tspan, y0, Nsteps, @runge_step);
[t2, y2] = ode_integrate(f, tspan, y0, Nsteps, @rk4_step);

% Plotte Loesung
figure(1);
clf;
hold on;
plot(t1, y1(:, 1))
plot(t2, y2(:, 1))
xlabel('t');
ylabel('y_{1}');
title('Loesung y_{1}')
legend('Heun Verfahren', 'RK4 Verfahren');
box on;
hold off;
% print('imag_ew_y1.eps','-depsc')
figure(2);
clf;
hold on;
plot(t1, y1(:, 2))
plot(t2, y2(:, 2))
xlabel('t');
ylabel('y_{2}');
title('Loesung y_{2}')
legend('Heun Verfahren', 'RK4 Verfahren');
box on;
hold off;
% print('imag_ew_y2.eps','-depsc')


% Implementation der Verfahren %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [t, y] = ode_integrate(f, tspan, y0, Nsteps, stepper)
% Integriere AWP mit stepper
  t = linspace(tspan(1), tspan(2), Nsteps + 1);
  dt = (tspan(2) - tspan(1))/(Nsteps + 1);
  y = zeros(Nsteps + 1, length(y0));
  y(1,:) = y0;
  for j=1:Nsteps
    y(j+1,:) = stepper(f, t(j), y(j,:), dt);
  end
end

function yjp = euler_exp_step(f, tj, yj, dt)
% Expliziter Euler Schritt
  yjp = yj + dt*f(tj, yj);
end

function yjp = euler_imp_step(f, tj, yj, dt)
% Impliziter Euler Schritt
  tjp = tj + dt;
  g = @(y) y - yj - dt*f(tjp, y);
  options = optimoptions('fsolve','Display','off');
  yjp = fsolve(g, yj, options);
end

function yjp = heun_step(f, tj, yj, dt)
% Heun Schritt
  k1 = f(tj, yj);
  k2 = f(tj + dt, yj + dt*k1);
  yjp = yj + 0.5*dt*(k1 + k2);
end

function yjp = runge_step(f, tj, yj, dt)
% Runge Schritt
  k1 = f(tj, yj);
  k2 = f(tj + 0.5*dt, yj + 0.5*dt*k1);
  yjp = yj + dt*k2;
end

function yjp = rk4_step(f, tj, yj, dt)
% RK4 Schritt
  k1 = f(tj, yj);
  k2 = f(tj + 0.5*dt, yj + 0.5*dt*k1);
  k3 = f(tj + 0.5*dt, yj + 0.5*dt*k2);
  k4 = f(tj + 0.5*dt, yj +     dt*k3);
  yjp = yj + dt*(k1 + 2.*k2 + 2.*k3 + k4)/6.;
end
